@@ -1,6 +1,7 @@
 use std::io::Result;
 use std::future::Future;
 use std::sync::Arc;
+use std::fmt::{Debug, Display, Formatter};
 
 use super::{IOStream, AsyncAccept, AsyncConnect};
 
@@ -21,6 +22,16 @@ pub struct TlsClientConf {
     pub early_data: bool,
 }
 
+impl Display for TlsClientConf {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(
+            f,
+            "sni: {}, insecure: {}, early_data: {}",
+            self.sni, self.insecure, self.early_data
+        )
+    }
+}
+
 #[derive(Clone)]
 pub struct TlsConnect<T> {
     conn: T,
@@ -28,6 +39,25 @@ pub struct TlsConnect<T> {
     cc: TlsConnector,
 }
 
+impl<T> Display for TlsConnect<T>
+where
+    T: Display,
+{
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result { write!(f, "[tls]{}", self.conn) }
+}
+
+impl<T> Debug for TlsConnect<T>
+where
+    T: Debug,
+{
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("TlsConnect")
+            .field("conn", &self.conn)
+            .field("sni", &self.sni)
+            .finish()
+    }
+}
+
 impl<T> TlsConnect<T> {
     pub fn new(conn: T, conf: TlsClientConf) -> Self {
         let TlsClientConf {
@@ -110,12 +140,38 @@ pub struct TlsServerConf {
     pub server_name: String,
 }
 
+impl Display for TlsServerConf {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(
+            f,
+            "cert: {}, key: {}, oscp: {}, server_name: {}",
+            self.crt, self.key, self.ocsp, self.server_name
+        )
+    }
+}
+
 #[derive(Clone)]
 pub struct TlsAccept<T> {
     lis: T,
     ac: TlsAcceptor,
 }
 
+impl<T> Display for TlsAccept<T>
+where
+    T: Display,
+{
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result { write!(f, "[tls]{}", self.lis) }
+}
+
+impl<T> Debug for TlsAccept<T>
+where
+    T: Debug,
+{
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("TlsAccept").field("lis", &self.lis).finish()
+    }
+}
+
 impl<T> TlsAccept<T> {
     pub fn new(lis: T, conf: TlsServerConf) -> Self {
         let TlsServerConf {
